@@ -733,7 +733,7 @@ enable_sensors (GUdevDevice *dev,
 	return ret;
 }
 
-static gboolean
+gboolean
 enable_ring_buffer (BufferDrvData *data)
 {
 	int ret;
@@ -754,12 +754,16 @@ enable_ring_buffer (BufferDrvData *data)
 	return TRUE;
 }
 
-static void
+void
 disable_ring_buffer (BufferDrvData *data)
 {
 	/* Stop the buffer */
 	write_sysfs_int ("buffer/enable", data->dev_dir_name, 0);
+}
 
+static void
+disable_trigger (BufferDrvData *data)
+{
 	/* Disconnect the trigger - just write a dummy name. */
 	if (data->trigger_name)
 		write_sysfs_string ("trigger/current_trigger", data->dev_dir_name, "NULL");
@@ -794,6 +798,64 @@ build_channels (BufferDrvData *data)
 	return TRUE;
 }
 
+char *
+get_trigger_name (GUdevDevice *device)
+{
+	GList *devices, *l;
+	GUdevClient *client;
+	gboolean has_trigger = FALSE;
+	char *trigger_name;
+	const gchar * const subsystems[] = { "iio", NULL };
+
+	client = g_udev_client_new (subsystems);
+	devices = g_udev_client_query_by_subsystem (client, "iio");
+
+	/*
+	 * Find the associated trigger using <device_name>-dev<device_number>
+	 * pattern, such as found on sensors using Intel HID Sensor Hub drivers
+	 */
+	trigger_name = g_strdup_printf ("%s-dev%s",
+					g_udev_device_get_sysfs_attr (device, "name"),
+					g_udev_device_get_number (device));
+	for (l = devices; l != NULL; l = l->next) {
+		GUdevDevice *dev = l->data;
+
+		if (g_strcmp0 (trigger_name, g_udev_device_get_sysfs_attr (dev, "name")) == 0) {
+			g_debug ("Found associated trigger (%s) at %s", trigger_name, g_udev_device_get_sysfs_path (dev));
+			has_trigger = TRUE;
+			break;
+		}
+	}
+
+	/*
+	 * If not found, search for trigger using the alternative <device_name>-trigger
+	 * naming convention
+	 */
+	if (!has_trigger) {
+		trigger_name = g_strdup_printf ("%s-trigger", g_udev_device_get_sysfs_attr (device, "name"));
+		for (l = devices; l != NULL; l = l->next) {
+			GUdevDevice *dev = l->data;
+
+			if (g_strcmp0 (trigger_name, g_udev_device_get_sysfs_attr (dev, "name")) == 0) {
+				g_debug ("Found associated trigger (%s) at %s", trigger_name, g_udev_device_get_sysfs_path (dev));
+				has_trigger = TRUE;
+				break;
+			}
+		}
+	}
+
+	g_list_free_full (devices, g_object_unref);
+	g_clear_object (&client);
+
+	if (has_trigger)
+		return trigger_name;
+
+	g_warning ("Could not find trigger name associated with %s",
+		   g_udev_device_get_sysfs_path (device));
+	g_free (trigger_name);
+	return NULL;
+}
+
 void
 buffer_drv_data_free (BufferDrvData *buffer_data)
 {
@@ -805,6 +867,7 @@ buffer_drv_data_free (BufferDrvData *buffer_data)
 	/* A buffer should be disabled before scan elements to avoid a
 	 * "Device or resource busy" error */
 	disable_ring_buffer (buffer_data);
+	disable_trigger (buffer_data);
 	g_free (buffer_data->trigger_name);
 
 	enable_sensors (buffer_data->device, 0);
@@ -840,6 +903,24 @@ buffer_drv_data_new (GUdevDevice *device,
 	return buffer_data;
 }
 
+gboolean
+is_buffer_usable (GUdevDevice *device)
+{
+	g_autofree char *trigger_name = NULL;
+	BufferDrvData *buffer_data;
+
+	trigger_name = get_trigger_name (device);
+
+	/* Temporarily enable the buffer to ensure the kernel driver is buffer-capable */
+	buffer_data = buffer_drv_data_new (device, trigger_name);
+	if (!buffer_data)
+		return FALSE;
+
+	/* Destroy buffer information until actually needed (in the .open call) */
+	g_clear_pointer (&buffer_data, buffer_drv_data_free);
+	return TRUE;
+}
+
 IIOSensorData *
 iio_sensor_data_new (gsize size)
 {
